[![Visistors](https://visitor-badge.glitch.me/badge?page_id=EterNomm.Whitehat)](https://github.com/EterNomm/Whitehat)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/whitehat?label=PyPI%20Downloads&logo=pypi&logoColor=yellow)](https://pypi.org/project/whitehat)
[![PyPI](https://img.shields.io/pypi/v/whitehat?label=PyPI%20Version&logo=pypi&logoColor=yellow)](https://pypi.org/project/whitehat)
[![PyPI - Status](https://img.shields.io/pypi/status/whitehat?label=Packages%20Status&logo=python&logoColor=lightblue)](https://pypi.org/project/whitehat#data)
[![GitHub repo size](https://img.shields.io/github/repo-size/EterNomm/Whitehat?label=Repo%20Size&logo=Github)](https://github.com/EterNomm/Whitehat)
[![GitHub stars](https://img.shields.io/github/stars/EterNomm/Whitehat?label=Stars)](https://github.com/EterNomm/Whitehat/stargazers)
[![GitHub forks](https://img.shields.io/github/forks/EterNomm/Whitehat?label=Forks)](https://github.com/EterNomm/Whitehat/network)
[![Discord](https://img.shields.io/discord/887650006977347594?color=blue&label=EterNomm&logo=discord&logoColor=lightblue)](https://discord.com/invite/qpT2AeYZRN)
[![Discord](https://img.shields.io/discord/835863428450877441?color=blue&label=NekoIceTeam&logo=discord&logoColor=lightblue)](https://discord.com/invite/hNtA2uEb7J)

# Whitehat

⚠️ **WARNING THIS PYTHON PACKAGES FOR EDUCATIONAL PURPOSES ONLY** ⚠️

## Key Features
- DDoS
- Key Logger
- Reverse Shell

## Features
- DDoS (Can up to 1500+ Requests per seconds)
- Get Phonenumber Info
- Get IP Address Information
- Keylogger
- Port Scanner
- Reverse Shell

## Install
- ### PIP
`pip install whitehat`

- ### Development Version
```
$ git clone https://github.com/EterNomm/Whitehat
$ cd whitehat
$ pip install .
```
or
```
$ pip install git+https://github.com/EterNomm/Whitehat
```

## Example
[Click here](https://github.com/EterNomm/Whitehat/tree/main/examples)


## Other
- Want to be a contributor? [Pull Request](https://github.com/EterNomm/Whitehat/pulls) are welcome :3
- Join our Discord Server [Here](https://discord.com/invite/qpT2AeYZRN)
